
print("Welcome to the KARaML Tools package (version 0.0.22)")

def respond():
    return "Response from karaml_tools.py" 

INSTALL_PATH = '/content/KARaML_Tools'

import os
INITIAL_DIR = os.getcwd()
if not os.path.exists(INSTALL_PATH):
  os.mkdir(INSTALL_PATH )
os.chdir(INSTALL_PATH )

import subprocess
subprocess.run(["pip", "-q", "install", "gdown"])
import gdown
gdown.download(id='14iuvYqoCWdUS_Adf3t1fBNS8tpOj-09Z', quiet=True)
from karaml_setup import *
os.chdir(INITIAL_DIR)




#print("Running __init__.py in karaml package")
print("Welcome to the KARaML Tools package (version 0.1.10)")
import os
HOST_DIR = os.getcwd()
if not os.path.exists('KARaML_Tools'):
  os.mkdir('KARaML_Tools')

import subprocess
subprocess.run(['pip', 'install', 'gdown==v4.6.3'])
import gdown
print("Using gdown version:", gdown.__version__)
gdown.download(id="1TjmLUBzDJg32A3YvI85PctAcSi4xsKVa",
               output='KARaML_Tools/karaml_setup.py',
               quiet=True)
os.chdir('KARaML_Tools')
import karaml_setup
os.chdir(HOST_DIR)




from setuptools import setup
setup(
    name='karaml',
    version='0.1.10',
    description='KARaML Tools wrapper package',
    long_description='Provides karaml_tools, a small package with the bare bones to get KARaML Tools running',
    url='https://bb-ai.net/KARaML/KARaML_Tools.html',
    author='brandonb',
    author_email='B.Bennett@leeds.ac.uk',
    packages=['karaml'],
    classifiers=['Development Status :: 1 - Planning'],
)
